@@ -63,7 +63,7 @@ npqcmstest <- function(formula,
     xdat = xdat[goodrows,,drop = FALSE]
     ydat = ydat[goodrows]
 
-    na.index = w(goodrows==0)
+    na.index = which(goodrows==0)
   }
 
   set.seed(random.seed)
