@@ -1,21 +1,23 @@
 npscoef <-
-  function(bws = stop(paste("bandwidths are required to perform the estimate!",
-             "please set 'bws'")), ...){
-    args = list(...)
-    
-if (is.recursive(bws)){
-    if (!is.null(bws$formula) && is.null(args$txdat))
-      UseMethod("npscoef",bws$formula)
-    else if (!is.null(args$data) || !is.null(args$newdata))
-      stop("data and newdata specified, but bws has no formula")
-    else if (!is.null(bws$call) && is.null(args$txdat))
-      UseMethod("npscoef",bws$call)
-    else
-      UseMethod("npscoef",bws)
-} else {
-      UseMethod("npscoef",bws)
-}
+  function(bws, ...){
+    args <- list(...)
 
+    if (!missing(bws)){
+      if (is.recursive(bws)){
+        if (!is.null(bws$formula) && is.null(args$txdat))
+          UseMethod("npscoef",bws$formula)
+        else if (!is.null(bws$call) && is.null(args$txdat))
+          UseMethod("npscoef",bws$call)
+        else if (!is.call(bws))
+          UseMethod("npscoef",bws)
+        else
+          UseMethod("npscoef",NULL)
+      } else {
+        UseMethod("npscoef", NULL)
+      }
+    } else {
+      UseMethod("npscoef", NULL)
+    }
   }
 
 npscoef.formula <-
@@ -70,44 +72,103 @@ npscoef.call <-
   }
 
 
-npscoef.default <-
-  function(bws,
-           txdat = stop("training data 'txdat' missing"),
-           tydat = stop("training data 'tydat' missing"),
-           tzdat = NULL,
-           exdat, eydat, ezdat,
-           residuals, errors, ...) {
+npscoef.default <- function(bws, txdat, tydat, tzdat, ...) {
+  sc.names <- names(sys.call())
 
-    miss.z <- missing(tzdat)
+  ## here we check to see if the function was called with tdat =
+  ## if it was, we need to catch that and map it to dat =
+  ## otherwise the call is passed unadulterated to npudensbw
+
+  bws.named <- any(sc.names == "bws")
+  txdat.named <- any(sc.names == "txdat")
+  tydat.named <- any(sc.names == "tydat")
+  tzdat.named <- any(sc.names == "tzdat")
+
+  no.bws <- missing(bws)
+  no.txdat <- missing(txdat)
+  no.tydat <- missing(tydat)
+  no.tzdat <- missing(tzdat)
+
+  ## if bws was passed in explicitly, do not compute bandwidths
     
+  if(txdat.named)
     txdat <- toFrame(txdat)
 
-    if (!miss.z)
-      tzdat <- toFrame(tzdat)
-    
-    if(!(is.vector(tydat) | is.factor(tydat)))
-      stop("'tydat' must be a vector")
+  if(tydat.named)
+    tydat <- toFrame(tydat)
 
-    tbw <- eval(parse(text=paste("npscoefbw(bws = bws, xdat = txdat, ydat = tydat,",
-                     ifelse(miss.z,"","zdat = tzdat,"),
-                     "bandwidth.compute = FALSE, ...)")))
+  if(tydat.named)
+    tzdat <- toFrame(tzdat)
 
-    tbw <-
-      updateBwNameMetadata(nameList = list(ynames = deparse(substitute(tydat))),
-                           bws = tbw)
+  mc <- match.call()
 
-    mc.names <- names(match.call(expand.dots = FALSE))
-    margs <- c("tzdat", "exdat", "eydat", "ezdat",  "residuals", "errors")
-    m <- match(margs, mc.names, nomatch = 0)
-    any.m <- any(m != 0)
+  tx.str <- ifelse(txdat.named, "xdat = txdat,",
+                   ifelse(no.txdat, "", "txdat,"))
+  ty.str <- ifelse(tydat.named, "ydat = tydat,",
+                   ifelse(no.tydat, "", "tydat,"))
+  tz.str <- ifelse(tzdat.named, "zdat = tzdat,",
+                   ifelse(no.tzdat, "", "tzdat,"))
+  
+  tbw <- eval(parse(text = paste("npscoefbw(",
+                      ifelse(bws.named,                             
+                             paste(tx.str, ty.str, tz.str,
+                                   "bws = bws, bandwidth.compute = FALSE,"),
+                             paste(ifelse(no.bws, "", "bws,"),
+                                   tx.str, ty.str, tz.str)),
+                      "call = mc, ...",")",sep="")))
 
+  ## tbw <-
+  ##  updateBwNameMetadata(nameList = list(ynames = deparse(substitute(tydat))),
+  ##                       bws = tbw)
 
-    eval(parse(text=paste("npscoef.scbandwidth(txdat=txdat, tydat=tydat, bws=tbw",
-                 ifelse(any.m, ",",""),
-                 paste(mc.names[m], ifelse(any.m,"=",""), mc.names[m], collapse=", "),
-                 ")")))
+  ## need to do some surgery on the call to
+  ## allow it to work with the formula interface
+
+  repair.args <- c("data", "subset", "na.action")
+  
+  m.par <- match(repair.args, names(mc), nomatch = 0)
+  m.child <- match(repair.args, names(tbw$call), nomatch = 0)
+  
+  if(any(m.child > 0)) {
+    tbw$call[m.child] <- mc[m.par]
   }
 
+  ## next we repair arguments portion of the call
+  m.bws.par <- match(c("bws","txdat","tydat","tzdat"), names(mc), nomatch = 0)
+  m.bws.child <- match(c("bws","txdat","tydat","tzdat"), as.character(tbw$call), nomatch = 0)
+  m.bws.union <- (m.bws.par > 0) & (m.bws.child > 0)
+  
+  tbw$call[m.bws.child[m.bws.union]] <- mc[m.bws.par[m.bws.union]]
+
+  environment(tbw$call) <- parent.frame()
+
+  ## because of some ambiguities in how the function might be called
+  ## we only drop up to two unnamed arguments, when sometimes dropping three
+  ## would be appropriate. 
+  ## also, for simplicity, we don't allow for inconsistent
+  ## mixes of named/unnamed arguments
+  ## so bws is named or unnamed, and t[xyz]dat collectively either
+  ## named or unnamed
+
+  tz.str <- ifelse(tzdat.named, ",tzdat = tzdat",
+                   ifelse(no.tzdat, "", "tzdat"))
+
+  if(no.bws){
+    tx.str <- ",txdat = txdat"
+    ty.str <- ",tydat = tydat"
+  } else {
+    tx.str <- ifelse(txdat.named, ",txdat = txdat","")
+    ty.str <- ifelse(tydat.named, ",tydat = tydat","")
+    if((!bws.named) && (!txdat.named)){
+      ty.str <- ifelse(tydat.named, ",tydat = tydat",
+                       ifelse(no.tydat, "", "tydat"))
+    }
+  }
+  
+  eval(parse(text=paste("npscoef(bws = tbw", tx.str, ty.str, tz.str, ",...)")))
+
+}
+
 npscoef.scbandwidth <-
   function(bws,
            txdat = stop("training data 'txdat' missing"),
